#Data boosting part of the Lingua system

dinorms.boost <- function(vect=NULL, powers=NULL, count=NULL, limit=0)
{
  if (!is.vector(vect))
    stop("vect should be a vector")
  if (!is.double(vect))
    stop("vect should be a vector of float-point numbers")
  if (0 < length(vect[is.na(vect)]))
    stop("NAs are not allowed here")
  if (-1 > min(vect))
    stop("vector values should be in [-1, 1] interval")
  if (1 < max(vect))
    stop("vector values should be in [-1, 1] interval")

  if (!is.vector(powers))
    stop("powers should be a vector")
  if (!is.double(powers))
    stop("powers should be a vector of float-point numbers")
  if (0 > min(powers))
    stop("powers values should be in [0, 1] interval")
  if (1 < max(powers))
    stop("powers values should be in [0, 1] interval")

  vect.length <- length(vect)
  if (vect.length != length(powers))
    stop("data vector and powers vector should have the same length")

  if (!is.vector(count))
    stop("count should be an integer")
  if (is.double(count))
    count <- as.integer(count)
  if (!is.integer(count))
    stop("count should be an integer")
  if (1 != length(count))
    stop("count should be an integer")
  if (0 >= count)
    stop("count should be a positive integer")

  if (!is.vector(limit))
    stop("limit should be a float-point number")
  if (is.integer(limit))
    limit <- as.double(limit)
  if (!is.double(limit))
    stop("limit should be a float-point number")
  if (1 != length(limit))
    stop("limit should be a float-point number")
  if (0 > limit[1])
    stop("limit should be >= 0")
  if (1 < limit[1])
    stop("limit should be <= 1")

  usage.inds <- powers >= limit
  usage.vect <- vect[usage.inds]
  usage.length <- length(usage.vect)

  if (0 == usage.length) {
    return(list(usage=0, desc=c(NA, NA), values=double(0)))
  }
  if (1 == usage.length) {
    val <- usage.vect[1]
    dins <- double(count)
    dins[] <- val
    return(list(usage=1, desc=c(val, NA), values=dins))
  }

  fdin <- function(usage.vect, usage.length) {
    vect.curr <- sample(seq(1:usage.length), usage.length, replace=TRUE)
    res <- .C("din_aggregate",
      as.integer(usage.length),
      as.double(usage.vect[vect.curr]),
      results = double(3),
      state = integer(1),
      PACKAGE = "libenduce")
    if (0 == res$state[1]) {
      return(NA)
    }
    return(res$results[3])
  }
  dins <- replicate(count, fdin(usage.vect, usage.length), simplify=TRUE)

  mid <- mean(dins)
  dis <- var(dins)
  return(list(usage=usage.length, desc=c(mid, dis), values=dins))
}



