#Data transformations part of the Lingua system

lingua.normalize <- function(vect=NULL, robust=FALSE)
{
  if (is.null(vect))
    stop("vector to normalize should be provided")
  if (!is.vector(vect))
    stop("vector to normalize should be provided")
  if (is.integer(vect))
    vact <- as.double(vect)
  if (!is.double(vect))
    stop("vector to normalize should be numeric")

  if (!is.vector(robust))
    stop("robustness should be logical value")
  if (!is.logical(robust))
    stop("robustness should be logical value")
  if (1 != length(robust))
    stop("robustness should be logical value")

  if (0 == length(vect[!is.na(vect)])) {
    return(vect)
  }

  if (!robust) {
    curmid <- mean(vect, na.rm=TRUE)
    curdis <- sd(vect, na.rm=TRUE)
    vect <- (vect - curmid) / curdis
  } else {
    curmid <- median(vect, na.rm=TRUE)
    curdis <- mad(vect, na.rm=TRUE)
    vect <- (vect - curmid) / curdis
  }

  return(vect)
}

lingua.unitize <- function(vect=NULL, method="linear", scale=0.0)
{
  METHODS <- c("linear", "normal", "exponential")
  DSCALES <- c(8.0, 4.0, 2.0)

  if (is.null(vect))
    stop("vector to unitize should be provided")
  if (!is.vector(vect))
    stop("vector to unitize should be provided")
  if (is.integer(vect))
    vact <- as.double(vect)
  if (!is.double(vect))
    stop("vector to unitize should be numeric")

  if (!is.character(method))
    stop("method type should be linear/normal/exponential")
  t1 <- pmatch(method, METHODS)
  if(is.na(t1))
    stop("method type should be linear/normal/exponential")

  if (!is.vector(scale))
    stop("unitize scale should be a numeric value")
  if (1 != length(scale))
    stop("unitize scale should be a numeric value")
  if (is.integer(scale))
    vact <- as.double(scale)
  if (!is.double(scale))
    stop("unitize scale should be a numeric value")
  if (0.0 > scale[1])
    stop("unitize scale should be a non-negative value")
  if (0.0 == scale)
    scale <- DSCALES[t1]

  if (3 == t1) {
    scale <- -1.0 / scale
    vect.length <- length(vect)
    expscale <- function(x, scale) {
      rv <- x
      neg <- FALSE
      if (0 > x) {
        neg <- TRUE
        x <- -1 * x
      }
      rv <- 1 - exp(scale * x)
      if (neg) {
        rv <- -1 * rv
      }
      return(rv)
    }
    vect <- apply(as.matrix(c(1:vect.length)), 1, expscale, scale=scale)
  }
  if (2 == t1) {
    vect <- (2 * pnorm(vect, sd=scale)) - 1
  }
  if (1 == t1) {
    negscale <- -1 * scale
    vect[scale < vect] <- vect
    vect[negscale > vect] <- negscale
    vect <- vect / scale
  }

  return(vect)
}



