#Data combinations part of the Lingua system

lingua.pairs <- function(data=NULL, mode="or", by.rows=FALSE)
{
  CONMODES <- c("and", "or")

  if (!is.matrix(data))
    stop("data should be a matrix")
  if (!is.numeric(data))
    stop("data should be a numeric matrix")

  if (!is.vector(mode))
    stop("by.rows should be a logical value")
  if (!is.character(mode))
    stop("mode should be and/or")
  if (1 != length(mode))
    stop("by.rows should be a logical value")
  t1 <- pmatch(mode, CONMODES)
  if(is.na(t1))
    stop("mode should be and/or")

  if (!is.vector(by.rows))
    stop("by.rows should be a logical value")
  if (!is.logical(by.rows))
    stop("by.rows should be a logical value")
  if (1 != length(by.rows))
    stop("by.rows should be a logical value")

  if (by.rows)
    data <- t(data)

  dims <- attributes(data)$dim
  exp <- dims[1]
  cnt <- dims[2]
  if (0 == exp)
    stop("empty data matrix")
  if (0 == cnt)
    stop("empty data matrix")
  if (2 > cnt) {
    return(list(count=0, indices=NULL, values=NULL))
    #stop("at least 2 properties to combine")
  }

  cmb.cnt <- cnt * (cnt-1) / 2

  func1 <- function(i, tot) {
    v <- vector(mode="integer", length=(tot+1-i))
    v[] <- i
    v
  }
  v1 <- unlist(apply(as.matrix(c(1:(cnt-1))), 1, func1, tot=(cnt-1)))

  func2 <- function(i, tot) {
    v <- as.integer(i:tot)
  }
  v2 <- unlist(apply(as.matrix(c(2:cnt)), 1, func2, tot=cnt))

  pairs.inds <- cbind(v1, v2)

  #combs <- matrix(0, nrow=exp, ncol=cmb.cnt)
  combs <- matrix()

  if (1 == t1) {
    combs <- apply(pairs.inds, 1, function(x) {pmin(data[, x[1]], data[, x[2]])})
  }
  if (2 == t1) {
    combs <- apply(pairs.inds, 1, function(x) {pmax(data[, x[1]], data[, x[2]])})
  }

  if (by.rows) {
    pairs.inds <- t(pairs.inds)
    combs <- t(combs)
  }

  #combs
  return(list(count=cmb.cnt, indices=pairs.inds, values=combs))
}

lingua.triplets <- function(data=NULL, mode="or", by.rows=FALSE)
{
  CONMODES <- c("and", "or")

  if (!is.matrix(data))
    stop("data should be a matrix")
  if (!is.numeric(data))
    stop("data should be a numeric matrix")

  if (!is.vector(mode))
    stop("by.rows should be a logical value")
  if (!is.character(mode))
    stop("mode should be and/or")
  if (1 != length(mode))
    stop("by.rows should be a logical value")
  t1 <- pmatch(mode, CONMODES)
  if(is.na(t1))
    stop("mode should be and/or")

  if (!is.vector(by.rows))
    stop("by.rows should be a logical value")
  if (!is.logical(by.rows))
    stop("by.rows should be a logical value")
  if (1 != length(by.rows))
    stop("by.rows should be a logical value")

  if (by.rows)
    data <- t(data)

  dims <- attributes(data)$dim
  exp <- dims[1]
  cnt <- dims[2]
  if (0 == exp)
    stop("empty data matrix")
  if (0 == cnt)
    stop("empty data matrix")
  if (3 > cnt) {
    return(list(count=0, indices=NULL, values=NULL))
    #stop("at least 3 properties to combine")
  }

  cmb.cnt <- cnt * (cnt-1) * (cnt-2) / 6

  func1 <- function(i, tot) {
    v <- vector(mode="integer", length=((tot-i)*(tot+1-i)/2))
    v[] <- i
    v
  }
  v1 <- unlist(apply(as.matrix(c(1:(cnt-2))), 1, func1, tot=(cnt-1)))

  func2.1 <- function(i, tot) {
    v <- vector(mode="integer", length=(tot+1-i))
    v[] <- i
    v
  }
  func2 <- function(i, tot) {
    v <- unlist(apply(as.matrix(c(i:(cnt-1))), 1, func2.1, tot=(cnt-1)))
  }
  v2 <- unlist(apply(as.matrix(c(2:(cnt-1))), 1, func2, tot=cnt))

  func3.1 <- function(i, tot) {
    v <- as.integer((i+1):tot)
    v
  }
  func3 <- function(i, tot) {
    v <- unlist(apply(as.matrix(c(i:(cnt-1))), 1, func3.1, tot=(cnt-0)))
  }
  v3 <- unlist(apply(as.matrix(c(2:(cnt-1))), 1, func3, tot=cnt))

  triplets.inds <- cbind(v1, v2, v3)

  #combs <- matrix(0, nrow=exp, ncol=cmb.cnt)
  combs <- matrix()

  if (1 == t1) {
    combs <- apply(triplets.inds, 1, function(x) {pmin(data[, x[1]], data[, x[2]], data[, x[3]])})
  }
  if (2 == t1) {
    combs <- apply(triplets.inds, 1, function(x) {pmax(data[, x[1]], data[, x[2]], data[, x[3]])})
  }

  if (by.rows) {
    triplets.inds <- t(triplets.inds)
    combs <- t(combs)
  }

  #combs
  return(list(count=cmb.cnt, indices=triplets.inds, values=combs))
}


