\name{Clustions}
\alias{Clustions}
\alias{clustions}
\alias{clustions.thresholds}
\alias{clustions.maxcycles}
\alias{clustions.cluster}
\alias{clustions.cluster2}
\title{ Clustions -  Notion clustering, based on contifiers }
\description{
  Clustions are for notion-wise clustering of [0,1]-valued data,
  possibly with the [-1,1] interval being used as compressed pairs
  of dichotomic data.
}
\usage{
clustions.thresholds(thresh)
clustions.maxcycles(maxcyc)
clustions.cluster(data.cases, ini.centers, by.rows=FALSE)
clustions.cluster2(data.cases, ini.centers, by.rows=FALSE)
}
\arguments{
  \item{thresh}{ either none or [0,1] value for the threshold }
  \item{maxcyc}{ either none or the maximal k-means cycling count }
  \item{data.cases}{ [0,1]-valued data vectors to aggregate }
  \item{ini.centers}{ initial centers for the clustering }
  \item{by.rows}{ having row-wise data properties to cluster }
}
\details{
  The clustering proceeds like k-means with the similarity metrics
  based on Contifiers, especially the product ones. Cases with
  zero-only values are neglected, greater similar values count for,
  greater dissimilar values count against similarities.
}
\value{
  \code{thresholds} and \code{maxcyc} give the set option values,
  \code{cluster} and \code{cluster2} give the clustering results.
}
\references{ Bioplexity www.bioplexity.org }
\author{ Martin Saturka }
\note{
  Look at the Bioplexity and Enduce webs for more information.
  http://www.bioplexity.org/analysis/
  http://www.tangloid.net/enduce/
}
\seealso{ See Also \code{\link{lingua}}, \code{\link{dinorms}}, \code{\link{contifiers}} }
\examples{
library(lingua)
## initial settings
contifiers.thresholds(c(0.1))
clustions.maxcycles(20)
## some random data matrix
data.cases <- matrix(runif(30), nrow=5, ncol=6)
## with some initial centers
ini.centers <- data.cases[,1:3]
## and to cluster it
clustions.cluster(data.cases, ini.centers)
## some [-1,1]-valued data (viewed as compressed pairs)
data.cases2 <- matrix(runif(30, -1, 1), nrow=5, ncol=6)
## some initial centers
ini.cens2neg <- -1 * data.cases2[,1:3]
ini.cens2neg[0.0 > ini.cens2neg] <- 0.0
ini.cens2pos <- data.cases2[,1:3]
ini.cens2pos[0.0 > ini.cens2pos] <- 0.0
ini.centers2 <- cbind(ini.cens2neg, ini.cens2pos)
## and to cluster it
clustions.cluster2(data.cases2, ini.centers2)
## columns were used as objects to cluster
}
\keyword{ cluster }

