\name{Contifiers}
\alias{Contifiers}
\alias{contifiers}
\alias{contifiers.thresholds}
\alias{contifiers.modes}
\alias{contifiers.aggregate}
\title{ Contifiers - Continuous-data association quantifiers }
\description{
  Contifiers are functors for aggregation of [0,1]-interval valued
  pairs when we look for relations (associations) between the pair items.
  Particular value pairs are for data cases, i.e. individual experiments
  or shopping carts.
}
\usage{
contifiers.thresholds(thresh)
contifiers.modes(modes)
contifiers.aggregate(vecx, vecy)
}
\arguments{
  \item{thresh}{ either none or [0,1] value for the threshold }
  \item{modes}{ either none or name-pair for directionality:
  one of "mutual", "directional", "inverse", and
  distance enumeration: one of "minimum", "product", "bold"
  \code{modes} }
  \item{vecx,vecy}{ [0,1]-valued data vectors to aggregate }
}
\details{
  The directional contifiers are for situations like "when
  \code{A} occurs then \code{B} frequently occurs too".
  It can be e.g. for expression of a gene \code{b} is triggered
  by a gene \code{a}. The mutual contifiers are for
  situations when the relation is bidirectional.
}
\value{
  \code{thresholds} and \code{modes} give the set option values,
  \code{aggregate} gives the aggregation results.
}
\references{ Bioplexity www.bioplexity.org }
\author{ Martin Saturka }
\note{
  Look at the Bioplexity and Enduce webs for more information.
  http://www.bioplexity.org/analysis/
  http://www.tangloid.net/enduce/
}
\seealso{ See Also \code{\link{lingua}}, \code{\link{dinorms}}, \code{\link{clustions}} }
\examples{
library(lingua)
## initial settings
contifiers.thresholds(c(0.1))
contifiers.modes(c("dir", "pro"))
## some random vectors
vecx <- runif(20)
vecy <- runif(20)
## making the aggregation
contifiers.aggregate(vecx, vecy)
}
\keyword{ multivariate }

