\name{Dinorms}
\alias{Dinorms}
\alias{dinorms}
\alias{dinorms.thresholds}
\alias{dinorms.modes}
\alias{dinorms.aggregate}
\alias{dinorms.boost}
\title{ Dinorms - Natural aggregation of dichotomic values }
\description{
  Dinorms are functions for aggregation of dichotomic values
  from the [-1,1] interval. The values are assumed to be supports
  for two opposite situations. It can be e.g. reasons for cold
  vs. hot situations, or underexpressed vs. overexpressed genes
  as reasons for positive vs. negative advices for a treatment.
}
\usage{
dinorms.thresholds(thresh = NULL)
dinorms.modes(modes = NULL)
dinorms.aggregate(vect)
dinorms.boost(vect, powers, count, limit = 0)
}
\arguments{
  \item{thresh}{ either none or vector of two [0,1] values
  for addition, combination thresholds }
  \item{modes}{ either none or name-pair for addition:
  one of "maximum", "coproduct", "summation", and
  combination: one of "maximum", "codivision", "subtraction",
  "stabilized" \code{modes} }
  \item{vect}{ [-1,1]-valued vector to aggregate }
  \item{powers}{ [0,1]-valued vector of data strengths }
  \item{count}{ number of resamples for the boosting }
  \item{limit}{ to use data with >= \code{limit} power }
}
\details{
  The Dinorms aggregation is based on fuzzy logic connectives,
  separated into twofold process. First, negative and positive values
  are aggregated separately in the natural way. Then the result values
  are combined into a final aggregation (e.g. prognosis).
}
\value{
  \code{thresholds} and \code{modes} give the set option values,
  \code{aggregate} gives the sequence of negative, positive,
  and combined results, \code{boost} gives strengthen results,
  with \code{desc} being c(mean, variance).
}
\references{ Bioplexity www.bioplexity.org }
\author{ Martin Saturka }
\note{
  Look at the Bioplexity and Enduce webs for more information.
  http://www.bioplexity.org/analysis/
  http://www.tangloid.net/enduce/
}
\seealso{ See Also \code{\link{lingua}}, \code{\link{contifiers}}, \code{\link{clustions}} }
\examples{
library(lingua)
## initial settings
dinorms.thresholds(c(0.1, 0.1))
dinorms.modes(c("cop", "sub"))
## aggregate some random vector
vect <- runif(20, -1, 1)
dinres <- dinorms.aggregate(vect)
## boosting the dinorms
powers <- runif(length(vect))
dinorms.boost(vect, powers, 10, 0.5)
}
\keyword{ multivariate }

