\name{Lingua}
\alias{Lingua}
\alias{lingua}
\alias{Lingua-package}
\alias{lingua-package}
\alias{lingua.normalize}
\alias{lingua.unitize}
\alias{lingua.pairs}
\alias{lingua.triplets}
\docType{lingua}
\title{
Lingua - logic-based data mining on gene expression data
}
\description{
Logic powered intriguing notions on gene microarray data.
Lingua contains applied logic-based methods for microarray data analysis,
e.g. for lookup of new notions out of microarray data.
\tabular{ll}{
Package: \tab lingua\cr
Type: \tab Package\cr
Version: \tab 1.0-1\cr
Date: \tab 2009-04-13\cr
License: \tab MIT\cr
LazyLoad: \tab no\cr
}
}
\usage{
lingua.normalize(vect, robust = FALSE)
lingua.unitize(vect, method = "linear", scale = 0)
lingua.pairs(data, mode = "or", by.rows = FALSE)
lingua.triplets(data, mode = "or", by.rows = FALSE)
}
\arguments{
  \item{vect}{ data vector \code{vect} to normalize }
  \item{robust}{ whether to do \code{robust} normalization }
  \item{method}{ linerar, normal, exponential \code{method} }
  \item{scale}{ forcing the result data density }
  \item{data}{ data matrix with properties to be combined}
  \item{mode}{ \code{or} for max, \code{and} for min combinations}
  \item{by.rows}{ having row-wise data properties }
}
\details{
Here, we present basic Lingua functions to do data set-up.
The main functionality is implemented via Dinorms, Contifiers,
and Clustions methods.
}
\value{
  \code{normalize} gives normalized vectors, \code{unitize} gives
  vectors set into the [-1,1] interval, \code{pairs} and \code{triplets}
  give data values of connectives-based tuplets.
}
\author{
Martin Saturka

Maintainer: Martin Saturka <martin.saturka@bioplexity.org>
}
\references{
Bioplexity - www.bioplexity.org
}
\note{
 Look at the Bioplexity web for more information.
 http://www.bioplexity.org/analysis/
}
\keyword{ package }
\keyword{ manip }
\seealso{
\code{\link{dinorms}}, \code{\link{contifiers}}, \code{\link{clustions}}
}
\examples{
library(lingua)
## data normalization into mean=0, var=1
vect <- rnorm(20, 7, 3)
vect <- lingua.normalize(vect)
## and putting the values into the [0,1] interval
lingua.unitize(vect, "normal", 1)
## combinations of data-matrix columns
data <- matrix(rnorm(20), nrow=5, ncol=4)
lingua.pairs(data, "or")
lingua.triplets(data, "and")
}

